#!/usr/bin/env bash
# Mon  8 Aug 17:40:24 2016 CEST

source $(dirname ${0})/functions.sh

if [ -z "${WHEELS_REPOSITORY}" ]; then
  WHEELS_REPOSITORY="${DOCSERVER}/software/bob/wheels/gitlab/"
  WHEELS_SERVER=`echo ${DOCSERVER} | sed 's;https\?://;;'`
  check_env WHEELS_SERVER
fi
check_env WHEELS_REPOSITORY

# Readies the virtualenv to use for installation
if [ ! -d ${PREFIX} ]; then
  log_info "Creating virtualenv installation at ${PREFIX}..."
  run_cmd ${BOB_PREFIX_PATH}/bin/virtualenv --system-site-packages ${PREFIX}
else
  log_warn "Prefix directory ${PREFIX} exists, not re-installing..."
fi

# Source the newly created virtualenv
log_info "$ source ${PREFIX}/bin/activate"
source ${PREFIX}/bin/activate

# Verify where pip is installed
use_pip=`which pip`
if [ -z "${use_pip}" ]; then
  log_error "Cannot find pip, aborting..."
  exit 1
else
  log_info "Using pip: ${use_pip}"
fi

# Upgrade wheel generation library to avoid bugs
run_cmd ${use_pip} install --upgrade setuptools pip wheel

use_python=`which python`
if [ -z "${use_python}" ]; then
  log_error "Cannot find python, aborting..."
  exit 1
else
  log_info "Using python: ${use_python}"
fi

# Install this package's build dependencies
PIPOPTS="--find-links ${WHEELS_REPOSITORY}"
if [ ! -z "${WHEELS_SERVER}" ]; then
 PIPOPTS="${PIPOPTS} --trusted-host ${WHEELS_SERVER}"
fi
PIPOPTS="${PIPOPTS} --pre --use-wheel --no-index"
if [ -e requirements.txt ]; then
  run_cmd ${use_pip} install ${PIPOPTS} --requirement requirements.txt
else
  log_info "No requirements.txt file found, skipping 'pip install <build-deps>'..."
fi

# Install this package's test dependencies
if [ -e test-requirements.txt ]; then
  run_cmd ${use_pip} install ${PIPOPTS} --requirement test-requirements.txt
else
  log_info "No test-requirements.txt file found, skipping 'pip install <test-deps>'..."
fi

# Finally, bootstrap the installation from the new environment
if [ -e bootstrap-buildout.py ]; then
  run_cmd ${use_python} bootstrap-buildout.py
else
  log_error "No bootstrap-buildout.py file found, stopping..."
  exit 1
fi
